/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                  Java Language Orientus SDK, Version 6.0                   */
/*                    Copyright 2022, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2022 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* Packet Periods */
public class ANPacket181
{
	public boolean permanent;
	public boolean clearExistingPacketPeriods;
	public int[] packetID;
	public long[] packetPeriod;

	public ANPacket181()
	{
	}

	public ANPacket181(ANPacket packet)
	{
		permanent = packet.data[0] != 0;
		clearExistingPacketPeriods = packet.data[1] != 0;
		packetID = new int[(packet.length-2)/5];
		packetPeriod = new long[packetID.length];
		for (int i = 2, j = 0; j < packetID.length; i = i + 5, j++)
		{
			packetID[j] = packet.data[i] & 0xFF;
			packetPeriod[j] = TypeConversion.bytesToUInt32(packet.data, i + 1);
		}
	}

	public ANPacket toANPacket() throws IndexOutOfBoundsException
	{
		ANPacket packet = new ANPacket(2 + 5 * packetID.length, ANPacket.PACKET_ID_PACKETS_PERIOD);
		packet.data[0] = (byte) (permanent ? 1 : 0);
		packet.data[1] = (byte) (clearExistingPacketPeriods ? 1 : 0);
		for (int i = 2, j = 0; j < packetID.length; i = i + 5, j++)
		{
			if (packetID[i] < 0) throw new IndexOutOfBoundsException();
			packet.data[i] = (byte) (packetID[j] & 0xFF);
			TypeConversion.int32ToBytes(packet.data, i + 1, (int) packetPeriod[j]);
		}
		return packet;
	}
}
